indexing
	description: "Representation of a year w/r/t a calendar"
	license: "Eiffel Forum License v2 - See license.txt"
	source: "{
		Amalasoft Corporation
		273 Harwood Avenue
		Littleton, MA 01460 USA
		}"
	status: "Copyright 1995-2008, Amalasoft"
	date: "$Date: 2008/04/26 $"
	revision: "$Revision: 002$"

class AEL_DT_CALENDAR_YEAR

inherit
	ARRAY [AEL_DT_CALENDAR_MONTH]
		rename
			make as array_make,
			out as array_out
		end

create
	make, make_filled

feature {NONE} -- Creation and initialization

	make (v: INTEGER; ij: BOOLEAN) is
		require
			valid_year: v > 0 and then v <= 9999
		do
			array_make (1, 12)
			year_number := v
			is_julian := ij
			is_leap_year := cal_routines.year_is_leap (year_number)
		end

	make_filled (v: INTEGER; ij: BOOLEAN) is
		do
			make (v, ij)
			make_months
		end

	make_months is
		local
			mo: AEL_DT_CALENDAR_MONTH
			idx: INTEGER
		do
			from idx := 1
			until idx > 12
			loop
				create mo.make (idx, Current)
				put (mo, idx)
				idx := idx + 1
			end
		end

feature -- Status

	year_number: INTEGER

	is_leap_year: BOOLEAN
			-- Is this year a leap year?

	is_julian: BOOLEAN
			-- Is this to be interpreted as a Julian date?

feature -- String representation

	out: STRING is
		local
			idx: INTEGER
			col: INTEGER
			tl: INTEGER
			row: INTEGER
			mn: INTEGER
		do
			create Result.make (2048)

			if is_julian then
				tl := 28
			else
				tl := 21
			end

			Result.append ("%N")
			Result.append (title_leader)
			Result.append_integer (year_number)
			Result.append ("%N%N")

			from idx := 1
			until idx > 4 -- 12 // 3
			loop
				Result.append (month_labels.item (idx))
				Result.extend ('%N')

				from row := 0
				until row > 6
				loop
					from col := 1
					until col > 3
					loop
						mn := ( (idx - 1) * 3) + col
						Result.append (item (mn).week_out (row))
						col := col + 1
						Result.append (Ks_gutter)
					end
					Result.prune_all_trailing (' ')
					Result.extend ('%N')
					row := row + 1
				end
				idx := idx + 1
			end
			Result.prune_all_trailing (' ')
			Result.extend ('%N')
		end

feature {NONE} -- Rendition support

	month_labels: ARRAY [STRING] is
		once
			Result := <<"	 Jan			Feb		       Mar",
			"	 Apr			May		       Jun",
			"	 Jul			Aug		       Sep",
			"	 Oct			Nov		       Dec"
			>>
		end

	title_leader: STRING is
		do
			if is_julian then
				Result := "					  "
			else
				Result := "				"
			end
		end

feature {NONE} -- Constants

	Ks_gutter: STRING is "  "

	cal_const: AEL_DATE_TIME_CONSTANTS is
		once
			create Result
		end

	cal_routines: AEL_DATE_TIME_ROUTINES is
		once
			create Result
		end

end -- class AEL_DT_CALENDAR_YEAR
